==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_fields/PARTNERINBOUNDDOCUMENTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour PARTNERINBOUNDDOCUMENTID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="PARTNERINBOUNDDOCUMENTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DATABRIDGEPARTNERID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INBOUNDDOCUMENTTYPE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PARTNERINBOUNDDOCUMENTID_Type", propOrder = {
    "databridgepartnerid",
    "inbounddocumenttype"
})
public class PARTNERINBOUNDDOCUMENTID_Type {

    @XmlElement(name = "DATABRIDGEPARTNERID", required = true)
    protected PARTNERID_Type databridgepartnerid;
    @XmlElement(name = "INBOUNDDOCUMENTTYPE", required = true)
    protected String inbounddocumenttype;

    /**
     * Obtient la valeur de la propriété databridgepartnerid.
     * 
     * @return
     *     possible object is
     *     {@link PARTNERID_Type }
     *     
     */
    public PARTNERID_Type getDATABRIDGEPARTNERID() {
        return databridgepartnerid;
    }

    /**
     * Définit la valeur de la propriété databridgepartnerid.
     * 
     * @param value
     *     allowed object is
     *     {@link PARTNERID_Type }
     *     
     */
    public void setDATABRIDGEPARTNERID(PARTNERID_Type value) {
        this.databridgepartnerid = value;
    }

    /**
     * Obtient la valeur de la propriété inbounddocumenttype.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getINBOUNDDOCUMENTTYPE() {
        return inbounddocumenttype;
    }

    /**
     * Définit la valeur de la propriété inbounddocumenttype.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setINBOUNDDOCUMENTTYPE(String value) {
        this.inbounddocumenttype = value;
    }

}

==> eam-wshub-proxyclient-11.7-3-sources.jar: net/datastream/schemas/mp_fields/PARTNERINBOUNDDOCUMENTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for PARTNERINBOUNDDOCUMENTID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="PARTNERINBOUNDDOCUMENTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DATABRIDGEPARTNERID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INBOUNDDOCUMENTTYPE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PARTNERINBOUNDDOCUMENTID_Type", propOrder = {
    "databridgepartnerid",
    "inbounddocumenttype"
})
public class PARTNERINBOUNDDOCUMENTID_Type {

    @XmlElement(name = "DATABRIDGEPARTNERID", required = true)
    protected PARTNERID_Type databridgepartnerid;
    @XmlElement(name = "INBOUNDDOCUMENTTYPE", required = true)
    protected String inbounddocumenttype;

    /**
     * Gets the value of the databridgepartnerid property.
     * 
     * @return
     *     possible object is
     *     {@link PARTNERID_Type }
     *     
     */
    public PARTNERID_Type getDATABRIDGEPARTNERID() {
        return databridgepartnerid;
    }

    /**
     * Sets the value of the databridgepartnerid property.
     * 
     * @param value
     *     allowed object is
     *     {@link PARTNERID_Type }
     *     
     */
    public void setDATABRIDGEPARTNERID(PARTNERID_Type value) {
        this.databridgepartnerid = value;
    }

    /**
     * Gets the value of the inbounddocumenttype property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getINBOUNDDOCUMENTTYPE() {
        return inbounddocumenttype;
    }

    /**
     * Sets the value of the inbounddocumenttype property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setINBOUNDDOCUMENTTYPE(String value) {
        this.inbounddocumenttype = value;
    }

}
